<?php

namespace Lavalite\Product\Forms;

use Litepie\Form\FormInterpreter;

class Product extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('product/product/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('product/product/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('product/product'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('product/product'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('product/product'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('product/product'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('product::product.label.name'),
                "placeholder" => trans('product::product.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('product::product.label.created_at'),
            'name' => trans('product::product.label.name'),
            'status' => trans('product::product.label.status'),
        ];
        self::$groups = [
            'main' => trans('product::product.groups.main'),
            'details' => trans('product::product.groups.details'),
            'images' => trans('product::product.groups.images'),
            'settings' => trans('product::product.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('product::product.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('product::product.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('product::product.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('product::product.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'name' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.name'),
                "placeholder" => trans('product::product.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'tagline' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.tagline'),
                "placeholder" => trans('product::product.placeholder.tagline'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'summary' => [
                "element" => 'textarea',
                "type" => 'textarea',
                "label" => trans('product::product.label.summary'),
                "placeholder" => trans('product::product.placeholder.summary'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'description' => [
                "element" => 'html_editor',
                "type" => 'html_editor',
                "label" => trans('product::product.label.description'),
                "placeholder" => trans('product::product.placeholder.description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "12",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'demo' => [
                "element" => 'textarea',
                "type" => 'textarea',
                "label" => trans('product::product.label.demo'),
                "placeholder" => trans('product::product.placeholder.demo'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'price' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('product::product.label.price'),
                "placeholder" => trans('product::product.placeholder.price'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'version' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.version'),
                "placeholder" => trans('product::product.placeholder.version'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'images' => [
                "element" => 'file',
                "type" => 'images',
                "label" => trans('product::product.label.images'),
                "placeholder" => trans('product::product.placeholder.images'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "12",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'tags' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.tags'),
                "placeholder" => trans('product::product.placeholder.tags'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'works_on' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.works_on'),
                "placeholder" => trans('product::product.placeholder.works_on'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
